import { __decorate } from "tslib";
import { attr, observable, volatile } from '@microsoft/fast-element';
import { FoundationElement } from '@microsoft/fast-foundation';
import dialogPolyfill from 'dialog-polyfill';
import { foundationDialogStyles as styles } from './dialog.styles';
import { foundationDialogTemplate as template } from './dialog.template';
// explicitly declaring for extensibility
export const foundationDialogShadowOptions = {
    mode: 'open',
    delegatesFocus: true,
};
export const defaultDialogConfig = {};
export class DialogElement extends FoundationElement {
    constructor() {
        super(...arguments);
        this.position = 'centre';
        /**
         * Whether or not to show the close icon
         */
        this.showCloseIcon = true;
    }
    connectedCallback() {
        super.connectedCallback();
        if (!window['HTMLDialogElement']) {
            dialogPolyfill.registerDialog(this.mainElement);
        }
        this.mainElement.addEventListener('close', () => {
            if (this.onCloseCallback)
                this.onCloseCallback();
        });
    }
    /**
     * Determine if the dialog is showing or closed.
     */
    get open() {
        return this.mainElement.hasAttribute('open');
    }
    /**
     * Remove the HTMLDialogElement from display
     */
    close() {
        this.mainElement['close']();
    }
}
__decorate([
    attr
], DialogElement.prototype, "position", void 0);
__decorate([
    attr({ mode: 'boolean', attribute: 'show-close-icon' })
], DialogElement.prototype, "showCloseIcon", void 0);
__decorate([
    observable
], DialogElement.prototype, "onShowCallback", void 0);
__decorate([
    observable
], DialogElement.prototype, "onCloseCallback", void 0);
__decorate([
    volatile
], DialogElement.prototype, "open", null);
/**
 * @tagname %%prefix%%-dialog
 */
export class Dialog extends DialogElement {
    show() {
        if (this.onShowCallback)
            this.onShowCallback();
        this.mainElement['show']();
    }
}
/**
 * The Foundation Dialog
 *
 * @public
 * @remarks
 * HTML Element: \<foundation-dialog\>
 */
export const foundationDialog = Dialog.compose(Object.assign({ baseName: 'dialog', styles,
    template, shadowOptions: foundationDialogShadowOptions }, defaultDialogConfig));
